@@ -1,4 +1,5 @@
 from execpeewee.mapping import PeeweeFields
+import inspect
 import pymysql
 import re
 
@@ -9,6 +10,7 @@ class PeeweeModel:
         peewee model builder connect args.
         """
         self.peewee_db = peewee_db
+        self.db_name = [k for k, v in inspect.currentframe().f_back.f_locals.items() if v is peewee_db][0]
         self.db = pymysql.connect(database=peewee_db.database, **peewee_db.connect_params)
         self.fields = PeeweeFields.get()
         self.unknown = PeeweeFields.UnknownField.__name__
@@ -29,7 +31,7 @@ class PeeweeModel:
         fields = '\n'+''.join([self.__fields_filter(i, exc_fields, s) for i in self.__connect(sql)])
         class_name = ''.join([i.capitalize() for i in table.split('_')])
         subclass = f'{s(4)}class Meta:\n' \
-                   f'{s(8)}database = {self.peewee_db.database}\n' \
+                   f'{s(8)}database = {self.db_name}\n' \
                    f"{s(8)}table_name = '{table}'\n" \
                    # f'{s(8)}# primary_key = CompositeKey("fields_1", "fields_2")\n'
         print(f'\nclass {class_name}(Model): {fields}\n{subclass}')
@@ -61,7 +63,8 @@ class PeeweeModel:
         return tables if '0' in choose else [table_list[int(i)] for i in choose]
 
     def __fields_filter(self, columns_info, exc_fields, s):
-        fields_type = re.sub(r'\(.*$', '', columns_info[1])
+        pattern = r'\(.*$'
+        fields_type = re.sub(pattern, '', columns_info[1])
         return (f'{s(4)}{columns_info[0]} = {self.fields.get(fields_type, self.unknown)}()  # {columns_info[1]}\n'
                 if self.__check_exc(columns_info, exc_fields) else '')
 
